@@ -8,7 +8,7 @@ import zlib
 from codecs import BOM_UTF16_BE
 from hashlib import md5
 
-VERSION = __version__ = '0.2.0'
+VERSION = __version__ = '0.5.0'
 
 
 def _to_bytes(item):
@@ -97,6 +97,15 @@ class Stream(Object):
         #: Compress the stream data if set to ``True``. Default is ``False``.
         self.compress = compress
 
+    def begin_marked_content(self, tag, property_list=None):
+        """Begin marked-content sequence."""
+        self.stream.append(f'/{tag}')
+        if property_list is None:
+            self.stream.append(b'BMC')
+        else:
+            self.stream.append(property_list)
+            self.stream.append(b'BDC')
+
     def begin_text(self):
         """Begin a text object."""
         self.stream.append(b'BT')
@@ -172,6 +181,10 @@ class Stream(Object):
         """End path without filling or stroking."""
         self.stream.append(b'n')
 
+    def end_marked_content(self):
+        """End marked-content sequence."""
+        self.stream.append(b'EMC')
+
     def end_text(self):
         """End text object."""
         self.stream.append(b'ET')
@@ -409,7 +422,18 @@ class Array(Object, list):
 
 class PDF:
     """PDF document."""
-    def __init__(self):
+    def __init__(self, version=b'1.7', identifier=None):
+        """Create a PDF document.
+
+        :param bytes version: PDF version.
+        :param bytes identifier: PDF file identifier.
+
+        """
+        #: PDF version, as :obj:`bytes`.
+        self.version = _to_bytes(version)
+        #: PDF file identifier.
+        self.identifier = identifier
+
         #: Python :obj:`list` containing the PDF’s objects.
         self.objects = []
 
@@ -458,6 +482,12 @@ class PDF:
         object_.number = len(self.objects)
         self.objects.append(object_)
 
+    @property
+    def page_references(self):
+        return tuple(
+            f'{object_number} 0 R'.encode('ascii')
+            for object_number in self.pages['Kids'][::3])
+
     def write_line(self, content, output):
         """Write line to output.
 
@@ -470,7 +500,7 @@ class PDF:
         self.current_position += len(content) + 1
         output.write(content + b'\n')
 
-    def write(self, output, version=b'1.7', identifier=None):
+    def write(self, output, version=None, identifier=None):
         """Write PDF to output.
 
         :param output: Output stream.
@@ -479,6 +509,9 @@ class PDF:
         :param bytes identifier: PDF file identifier.
 
         """
+        version = self.version if version is None else _to_bytes(version)
+        identifier = self.identifier if identifier is None else identifier
+
         # Write header
         self.write_line(b'%PDF-' + version, output)
         self.write_line(b'%\xf0\x9f\x96\xa4', output)
